pub struct Set {
pub sponsor: Pubkey,
pub chain_id_account: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for Set.
Fields
sponsor: Pubkeychain_id_account: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for Setwhere
Pubkey: BorshSerialize,
impl BorshSerialize for Setwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for Set
impl ToAccountMetas for Set
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for Set
impl RefUnwindSafe for Set
impl Send for Set
impl Sync for Set
impl Unpin for Set
impl UnsafeUnpin for Set
impl UnwindSafe for Set