pub struct Set {
pub chain_id: String,
}Expand description
Instruction.
Fields
chain_id: StringTrait Implementations
Sourceimpl BorshDeserialize for Setwhere
String: BorshDeserialize,
impl BorshDeserialize for Setwhere
String: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Setwhere
String: BorshSerialize,
impl BorshSerialize for Setwhere
String: BorshSerialize,
Sourceimpl Discriminator for Set
impl Discriminator for Set
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for Set
impl InstructionData for Set